<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>Gestor de utilizadores MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administração</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Adicionar novo utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Adicionar conta de utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Re-introduzir a senha para o novo utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>confirmar a senha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Username of new user</source>
        <translation>Nome de utilizador do novo utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>User login name:</source>
        <translation>Nome de acesso do utilizador:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <location filename="../mainwindow.ui" line="416"/>
        <location filename="../mainwindow.ui" line="1134"/>
        <source>Enter username of new user</source>
        <translation>Nome de utilizador do novo utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="422"/>
        <source>username</source>
        <translation>nome de utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Password for new user</source>
        <translation>Senha para o novo utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>User password:</source>
        <translation>Senha de utilizador:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Enter password for new user</source>
        <translation>Introduzir a senha para o novo utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>password</source>
        <translation>senha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Confirm user password:</source>
        <translation>Confirmar a senha do utilizador:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Delete User Account</source>
        <translation>Eliminar a conta de utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Select user</source>
        <translation>Seleccionar utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.ui" line="1222"/>
        <location filename="../mainwindow.ui" line="1346"/>
        <location filename="../mainwindow.ui" line="1368"/>
        <source>Select user to delete</source>
        <translation>Seleccionar o utilizador a eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>User to delete:</source>
        <translation>Utilizador a eliminar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Eliminar também o directório &apos;home&apos; do utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Delete user home directory</source>
        <translation>Eliminar a directoria &apos;home&apos; do utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Rename User Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to modify:</source>
        <translation>Seleccionar o utilizador a modificar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>New user name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Change User Password</source>
        <translation>Alterar a Senha de Utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>new password</source>
        <translation>nova senha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Confirm new password:</source>
        <translation>Confirmar a nova senha:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>confirm new password</source>
        <translation>confirmar a nova senha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>New user password:</source>
        <translation>Nova senha de utilizador:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Repair a user configuration</source>
        <translation>Reparar uma configuração de utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Modify User Account</source>
        <translation>Alterar Conta de Utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Select user to repair</source>
        <translation>Selecionar utilizador a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>User to change:</source>
        <translation>Utilizador a alterar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>Restore Defaults</source>
        <translation>Restabelecer predefinições</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Restablecer as configurações do navegador para as pré-definições do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="651"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Configurações para Mozilla (Iceweasel ou Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Restabelecer a pertença a grupos para as pré-definições do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Group memberships</source>
        <translation>Pertença a grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Change Autologin Settings</source>
        <translation>Alterar as configurações de Acesso Automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Log in automatically</source>
        <translation>Iniciar sessão automaticamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Require password to log in</source>
        <translation>Palavra-passe requerida para iniciar sessão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy/Sync</source>
        <translation>Copiar/Sincronizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Copy Between Desktops</source>
        <translation>Copiar entre Ambientes de Trabalho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Select desktop to copy from</source>
        <translation>Seleccionar o ambiente de trabalho de onde copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>Select to only copy files</source>
        <translation>Selecionar apenas para copiar ficheiros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Copy only</source>
        <translation>Apenas copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Select desktop to copy to</source>
        <translation>Seleccionar o ambiente de trabalho para onde copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>Copy to:</source>
        <translation>Copiar para:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Copy from:</source>
        <translation>Copiar de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Select to copy and then delete differences</source>
        <translation>Seleccionar para copiar e de seguida eliminar diferenças</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="854"/>
        <source>Sync</source>
        <translation>Sincronizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select to copy/sync Shared</source>
        <translation>Seleccionar para copiar/sincronizar Partilhado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="903"/>
        <source>Shared folder</source>
        <translation>Pasta partilhada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Select to copy/sync entire home</source>
        <translation>Seleccionar para copiar/sincronizar toda a pasta home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Entire home</source>
        <translation>Toda a pasta home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Seleccionar para copiar/sincronizar a configuração do navegador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="938"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Mozilla (Firefox ou Iceweasel) configs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="951"/>
        <source>Select to copy/sync Documents</source>
        <translation>Seleccionar para copiar/sincronizar a pasta Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Documents folder</source>
        <translation>Pasta Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>What to copy/sync:</source>
        <translation>O que copiar/sincronizar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="977"/>
        <source>Progress</source>
        <translation>Progresso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1007"/>
        <location filename="../mainwindow.ui" line="1023"/>
        <source>Status of the changes</source>
        <translation>Estado das alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1026"/>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1042"/>
        <source>Progress of the changes</source>
        <translation>Progresso das alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1079"/>
        <source>Add/Remove Groups</source>
        <translation>Adicionar/Remover grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1091"/>
        <source>Add Group</source>
        <translation>Adicionar grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1121"/>
        <source>Group name:</source>
        <translation>Nome de grupo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>groupname</source>
        <translation>nome de grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1169"/>
        <source>Delete Group</source>
        <translation>Eliminar grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1231"/>
        <source>Group to delete:</source>
        <translation>Grupo a eliminar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Group Membership</source>
        <translation>Pertença a grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1375"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Grupos a que o utilizador pertence (alterar os grupos marcando ou desmarcando as respetivas caixas):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1395"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>Verifique as escolhas antes de aplicar. Atribuir pertenças a grupos errados pode danificar o sistema. Se cometer algum erro, use o separador Reparar para restabelecer as pertenças originais.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Apply any changes</source>
        <translation>Aplicar alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar alterações e sair</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1475"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Display help </source>
        <translation>Exibir a ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1526"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1533"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1540"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1543"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="112"/>
        <location filename="../mainwindow.cpp" line="174"/>
        <location filename="../mainwindow.cpp" line="182"/>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="219"/>
        <location filename="../mainwindow.cpp" line="242"/>
        <location filename="../mainwindow.cpp" line="250"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <location filename="../mainwindow.cpp" line="690"/>
        <location filename="../mainwindow.cpp" line="718"/>
        <location filename="../mainwindow.cpp" line="726"/>
        <location filename="../mainwindow.cpp" line="916"/>
        <location filename="../mainwindow.cpp" line="1029"/>
        <source>none</source>
        <translation>nenhuma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>A configuração de utilizador será reparada. Fechar todas as outras aplicações agora. Quando concluído, sair da sessão ou reiniciar. Proceder à reparação agora?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <location filename="../mainwindow.cpp" line="312"/>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <location filename="../mainwindow.cpp" line="312"/>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Autologin options</source>
        <translation>Opções de acesso automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>O acesso automático foi desativado para  a conta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>O acesso automático foi ativado para  a conta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>É necessário especificar um destino onde &apos;copiar para&apos;. Não se pode copiar para o ambiente de trabalho da sessão.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Antes de copiar, feche todas as outras aplicações. Certifique-se de que o destino de &apos;copiar para&apos; é suficientemente grande para receber todos os ficheiros a copiar. copiar entre ambientes de trabalho pode escrever por cima de, ou apagar, ficheiros ou preferências no ambiente de trabalho de destino. Pretende continuar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Synchronizing desktop...</source>
        <translation>A sincronizar ambiente de trabalho...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Copying desktop...</source>
        <translation>A copiar o ambiente de trabalho...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>O nome de utilizador tem que ter pelo menos 2 caracteres. Escolha um nome de utilizador mais comprido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>O nome de utilizador tem que estar em minúsculas
e não pode conter caracteres especiais ou espaços.
Escolha outro nome de utilizador.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>As senhas não coincidem. Tente de novo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>A senha tem que ter pelo menos 2 caracteres. Escolha uma senha mais longa.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>The user was added ok.</source>
        <translation>O utilizador foi adicionado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>Failed to add the user.</source>
        <translation>A adição do utilizador falhou.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Password successfully changed.</source>
        <translation>A senha foi alterada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Failed to change password.</source>
        <translation>Falha na alteração da senha.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Esta acção não pode ser revertida. Tem a certeza de que pretende eliminar o utilizador %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>The user has been deleted.</source>
        <translation>O utilizador foi eliminado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Failed to delete the user.</source>
        <translation>A eliminação do utilizador falhou.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>O nome de grupo tem que ter pelo menos 2 caracteres. Escolha um nome mais comprido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>O nome de grupo tem que estar em minúsculas
e não pode conter carácteres especiais ou espaços.
Escolha outro nome de utilizador.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>The system group was added ok.</source>
        <translation>O grupo foi addicionado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <source>Failed to add the system group.</source>
        <translation>A adição do grupo falhou.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Esta accção não pode ser revertida. Tem a certeza de que pretende eliminar o utilizador %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="499"/>
        <source>The group has been deleted.</source>
        <translation>O grupo foi eliminado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Failed to delete the group.</source>
        <translation>A eliminação do grupo falhou.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>The changes have been applied.</source>
        <translation>As alterações foram aplicadas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Failed to apply group changes</source>
        <translation>A aplicação das alterações falhou</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>The selected user name is currently in use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="561"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>The user was renamed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="595"/>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Synchronizing desktop...ok</source>
        <translation>A sincronizar ambiente de trabalho... concluído.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="597"/>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Copying desktop...ok</source>
        <translation>A copiar ambiente de trabalho... concluído.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Synchronizing desktop...failed</source>
        <translation>A sincronizar ambiente de trabalho... falhou</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Copying desktop...failed</source>
        <translation>A copiar ambiente de trabalho... falhou</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <location filename="../mainwindow.cpp" line="968"/>
        <location filename="../mainwindow.cpp" line="976"/>
        <source>browse...</source>
        <translation>percorrer...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="853"/>
        <source>About MX User Manager</source>
        <translation>Sobre o MX_Gestor de utilizadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="854"/>
        <source>MX User Manager</source>
        <translation>Gestor de utilizadores MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="856"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Conficuração simples de utilizador para o Linux MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="857"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="859"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="860"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="969"/>
        <source>Select folder to copy to</source>
        <translation>Seleccionar pasta para onde copiar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="41"/>
        <source>You must run this program as root.</source>
        <translation>Tem que executar este programa como administrador (root).</translation>
    </message>
</context>
</TS>
